=============
gnocchiclient
=============

.. image:: https://travis-ci.org/gnocchixyz/python-gnocchiclient.png?branch=master
    :target: https://travis-ci.org/gnocchixyz/python-gnocchiclient
    :alt: Build Status

.. image:: https://badge.fury.io/py/gnocchiclient.svg
    :target: https://badge.fury.io/py/gnocchiclient

Python bindings to the Gnocchi API

This is a client for Gnocchi API. There's :doc:`a Python API <api>` (the
:mod:`gnocchiclient` module), and a :doc:`command-line script <shell>`
(installed as :program:`gnocchi`). Each implements the entire Gnocchi API.

* Free software: Apache license
* Documentation: http://gnocchi.xyz/gnocchiclient
* Source: https://github.com/gnocchixyz/python-gnocchiclient
* Bugs: https://github.com/gnocchixyz/python-gnocchiclient/issues
